@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -95,7 +95,7 @@ checkset *checkset_merge(checkset *new, checkset *old,
       if (nic->regular.switches)
 	die(__FUNCTION__,
 	    "Error: cascading switches in non-inheriting "
-	    "checkset for file(%s)\n", filename);
+	    "checkset for file(%s)", filename);
 
       /* just juggle pointers to avoid copying. */
       nic->regular.switches	 = old->switches;
