@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -28,7 +28,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 typedef struct dbinfo {	/* file information for the database */
   struct stat	stat;
-  unsigned char	sum[SHA1_DIGEST_LENGTH];
+  unsigned char	sum[DIGEST_LENGTH];
 } dbinfo;
 
 #endif
