@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -38,7 +38,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #else
 #error No stdint.h or inttypes.h found.
 #endif
-#include	"gnupg/sha1.h"
+#include	"digest.h"
 #include	"cdb.h"
 #include	"cdb_make.h"
 #include	"cdb_get.h"
@@ -114,15 +114,15 @@ static unsigned long fileinfo_ruleset(integrit_t *it, fileinfo *inf)
  */
 inline static int do_checksum(integrit_t *it, fileinfo *inf)
 {
-    SHA1_CONTEXT	context;
-    char	buf[BUFSIZ];
-    int		n;
-    struct stat	fd_sb;		/* file-descriptor-based stat buffer */
-    int		fd;
-    dbinfo	*dbinf	 = &inf->dbinf;
+    DIGEST_CONTEXT	context;
+    char		buf[BUFSIZ];
+    int			n;
+    struct stat		fd_sb;		/* file-descriptor-based stat buffer */
+    int			fd;
+    dbinfo		*dbinf	 = &inf->dbinf;
     struct utimbuf	utb;	/* for resetting access time */
 
-    sha1_init(&context);
+    digest_init(&context);
 
     /*
      * For a symlink, read the name in the symlink as if it were "contents".
@@ -132,10 +132,12 @@ inline static int do_checksum(integrit_t *it, fileinfo *inf)
     if (S_ISLNK(inf->dbinf.stat.st_mode)) {
       int ret;
       ret = readlink(inf->path, buf, BUFSIZ);
-      if (ret < 0)
-	die(__FUNCTION__, "Error: could not readlink symlink (%s): %s\n",
-	    inf->path, strerror(errno));
-      sha1_write(&context, (uint8_t*) buf, ret);
+      if (ret < 0) {
+	warn(__FUNCTION__, "Warning: could not readlink symlink (%s): %s",
+	     inf->path, strerror(errno));
+	return 0;
+      }
+      digest_write(&context, (uint8_t*) buf, ret);
     } else {
       if ( (fd = open(inf->path, O_RDONLY)) == -1) {
         warn(__FUNCTION__, "Warning: could not open file (%s) for reading: %s",
@@ -143,18 +145,18 @@ inline static int do_checksum(integrit_t *it, fileinfo *inf)
         return 0;			/* didn't do checksum */
       }
       if (fstat(fd, &fd_sb) == -1)
-        die(__FUNCTION__, "Error: could not fstat file (%s): %s\n",
+        die(__FUNCTION__, "Error: could not fstat file (%s): %s",
 	    inf->path, strerror(errno));
 
       /* check that the file we've opened is the same one we did lstat on */
       if (fd_sb.st_ino != inf->dbinf.stat.st_ino) {
-        warn(__FUNCTION__, "Warning: file (%s) changed before we opened it\n",
+        warn(__FUNCTION__, "Warning: file (%s) changed before we opened it",
 	     inf->path);
         return 0;			/* didn't do checksum */
       }
       /* if read fails, n gets -1 */
       while ( (n = read(fd, buf, BUFSIZ)) > 0)
-        sha1_write(&context, (uint8_t*) buf, n);
+        digest_write(&context, (uint8_t*) buf, n);
 
       if (n == -1)		/* read error */
         warn(__FUNCTION__, "Warning: read from file (%s) failed: %s",
@@ -163,11 +165,8 @@ inline static int do_checksum(integrit_t *it, fileinfo *inf)
       close(fd);
     }
 
-    sha1_final(&context);
-    /* It is faster but slightly dirtier to use context.buf directly.
-     */
-    /* memcpy(dbinf->sum, sha1_read(&context), SHA1_DIGEST_LENGTH); */
-    memcpy(dbinf->sum, context.buf, SHA1_DIGEST_LENGTH);
+    digest_final(&context);
+    memcpy(dbinf->sum, digest_read(&context), DIGEST_LENGTH);
 
     /* reset access time on request */
     if (fileinfo_ruleset(it, inf) & RULE_RESET_ATIME) {
@@ -442,11 +441,15 @@ static void report_differences(integrit_t *it, fileinfo *currinf)
 
       /* if it's a regular file or symlink */
       if (flags & RULE_SUM) {
+	/* clean the old checksum buffer when needed */
+	if (knownsiz != sizeof(old))
+	  memset(old.sum, 0, DIGEST_LENGTH);
+
 	if (! currinf->did_sum)
 	  currinf->did_sum	 = do_checksum(it, currinf);
 
-	if (currinf->did_sum
-	    && memcmp(currinf->dbinf.sum, old.sum, sizeof(old.sum)))
+	if (currinf->did_sum &&
+	    memcmp(currinf->dbinf.sum, old.sum, sizeof(old.sum)))
 	  report_sumchange(it, path, old.sum, sizeof(old.sum),
 			   currinf->dbinf.sum, sizeof(currinf->dbinf.sum));
       }
@@ -474,7 +477,6 @@ static void report_newfile(integrit_t *it, fileinfo *inf)
     char		*path	 = inf->path;
     struct stat		*s	 = &inf->dbinf.stat;
     unsigned long	flags	 = fileinfo_ruleset(it, inf);
-    unsigned char	zerosum[SHA1_DIGEST_LENGTH];
 
     switch (it->output) {
       case OUTPUT_XML:
@@ -511,15 +513,15 @@ static void report_newfile(integrit_t *it, fileinfo *inf)
 	break;
     }
     putc('\n', stdout);
-    /* If it's a regular file or symlink, report an SHA-1 change */
+    /* If it's a regular file or symlink, show the checksum */
     if (S_ISREG(s->st_mode) || S_ISLNK(s->st_mode)) {
       if (flags & RULE_SUM) {
         if (! inf->did_sum)
           inf->did_sum	 = do_checksum(it, inf);
         if (inf->did_sum) {
-          memset(zerosum, 0, SHA1_DIGEST_LENGTH);
-          report_sumchange(it, path, zerosum, sizeof(zerosum),
-               inf->dbinf.sum, sizeof(inf->dbinf.sum));
+	  printf("new:     %s   ", path);
+	  show_checksum(stdout, inf->dbinf.sum, sizeof(inf->dbinf.sum));
+	  putc('\n', stdout);
         }
       }
     }
@@ -543,23 +545,30 @@ inline static void do_check(integrit_t *it, fileinfo *inf)
     }
 }
 
-inline static void do_update(integrit_t *it, fileinfo *inf)
+inline static int do_update(integrit_t *it, fileinfo *inf)
 {
     struct cdb_make	*db	 = &it->currdb;
     dbinfo		*dbinf	 = &inf->dbinf;
     size_t		datasiz;
     
     if (S_ISREG(dbinf->stat.st_mode) ||
-	S_ISLNK(dbinf->stat.st_mode))
-      /* BUGGISH: don't test inf->did_sum, since this function's called
-       *          before do_check (very minorly buggish :)
-       */
-      inf->did_sum	 = do_checksum(it, inf);
+	S_ISLNK(dbinf->stat.st_mode)) {
+      if (fileinfo_ruleset(it, inf) & RULE_SUM) {
+	/* BUGGISH: don't test inf->did_sum, since this function's called
+	 *          before do_check (very minorly buggish :)
+	 */
+	inf->did_sum	 = do_checksum(it, inf);
+        if (! inf->did_sum)
+	  return 0;
+      }
+    }
 
     datasiz	 = inf->did_sum ? sizeof(*dbinf) : sizeof(dbinf->stat);
 
     if (cdb_put(db, inf->path, inf->pathlen, dbinf, datasiz) == -1)
       DIE("adding record to current-state db");
+
+    return 1;
 }
 
 wft_ret_t process_file(const char *path, const struct stat *sb, void *data)
@@ -615,8 +624,12 @@ wft_ret_t process_file(const char *path, const struct stat *sb, void *data)
 
     memcpy(&inf.dbinf.stat, sb, sizeof(inf.dbinf.stat));
 
-    if (it->do_update)
-      do_update(it, &inf);
+    if (it->do_update) {
+      if (! do_update(it, &inf)) {
+	free(pathcopy);
+	return WFT_ERROR;
+      }
+    }
 
     if (it->do_check)
       do_check(it, &inf);
