@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -44,6 +44,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include	"xstradd.h"
 #include	"elcwft.h"
 #include	"elcwft_p.h"
+#include	"elcerror.h"
+#include	"elcerror_p.h"
 #ifdef		ELC_FIND_LEAKS
 #include	"leakfind.h"
 #endif
@@ -119,6 +121,7 @@ int walk_file_tree(wft_context_t *ctx)
     struct stat		statbuf;
     int			ret, cb_ret;
     int			done	 = 0;
+    int			err	 = 0;
 
     dirs.dir	 = root;
     dirs.next	 = NULL;
@@ -155,24 +158,24 @@ int walk_file_tree(wft_context_t *ctx)
 	}
 	cb_ret	= ctx->callback(path, &statbuf, ctx->cb_data);
 	switch (cb_ret) {
-	case WFT_STOP:
-	  done = 1;
-	  break;
+	case WFT_ERROR:
+	  if (ctx->options & WFT_STOP_ON_ERR)
+	    return WFT_ERROR;
+          err = 1;
+
 	case WFT_PRUNE:
 	  continue;
-	case WFT_ERROR:
-	  return WFT_ERROR;
 	}
 
 	if (ret == 1) { /* directory */
 	  if (! (np->next = malloc(sizeof(* np->next))) )
 	    return WFT_ERROR;
 	  if (! (np->next->dir = opendir(path)) ) {
-	    if (ctx->options & WFT_VERBOSE)
-	      fprintf(stderr, "Warning: cannot open directory (%s): %s\n",
-		      path, strerror(errno));
-	    if (! (ctx->options & WFT_IGNORE_OPENDIR_FAIL) )
-	      return WFT_OPENDIR_FAIL;
+	    warn(__FUNCTION__, "Warning: cannot open directory (%s): %s",
+		 path, strerror(errno));
+	    if (ctx->options & WFT_STOP_ON_ERR)
+	      return WFT_ERROR;
+	    err = 1;
 	    continue;
 	  }
 	  free(curr_dirname);
@@ -185,6 +188,6 @@ int walk_file_tree(wft_context_t *ctx)
     if (path)
       free(path);
     free(curr_dirname);
-    return 0;
+    return (err? WFT_SOME_ERR: WFT_PROCEED);
 }
 
