@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -21,14 +21,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define	ELC_WFT_H
 
 #define	WFT_VERBOSE		0x01
-#define	WFT_IGNORE_OPENDIR_FAIL	0x02
+#define	WFT_STOP_ON_ERR		0x02
 
 typedef enum wft_ret_t {
   WFT_ERROR	 = -1,
-  WFT_OPENDIR_FAIL = 1,
   WFT_PROCEED	 = 0,
-  WFT_PRUNE,
-  WFT_STOP,
+  WFT_SOME_ERR,
+  WFT_PRUNE
 } wft_ret_t;
 
 /* callback type */
