@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,13 +22,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 enum integrit_output {
   OUTPUT_LINES,			/* human-readable lines output */
-  OUTPUT_XML,			/* XML output */
+  OUTPUT_XML			/* XML output */
 };  
 
 enum integrit_exit_status {
   INTEGRIT_EXIT_NOCHANGE = 0,
   INTEGRIT_EXIT_CHANGES = 1,
-  INTEGRIT_EXIT_FAILURE = 2,
+  INTEGRIT_EXIT_FAILURE = 2
 };
   
 typedef struct integrit {
@@ -46,6 +46,7 @@ typedef struct integrit {
   int			verbose;
   unsigned long		default_flags;
   enum integrit_output	output;	/* type of output */
+  unsigned		stop_on_err: 1;	/* stop on errors */
   unsigned		do_check: 1;	/* test files against known-state db */
   unsigned		do_update: 1;	/* generate current-state db */
 } integrit_t;
