@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
-/* $Header: /cvsroot/integrit/integrit/main.c,v 1.28 2005/09/13 00:47:39 ecashin Exp $ */
+/* $Header: /cvsroot/integrit/integrit/main.c,v 1.31 2006/04/07 09:41:10 wavexx Exp $ */
 #include	<config.h>
 #include	<stdio.h>
 #include	<unistd.h>
@@ -34,7 +34,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #else
 #error No stdint.h or inttypes.h found.
 #endif
-#include	"gnupg/md5.h"
+#include	"digest.h"
 #include	"cdb.h"
 #include	"cdb_make.h"
 #include	"hashtbl/hashtbl.h"
@@ -97,37 +97,32 @@ static void close_known_cdb(integrit_t *it)
 
 static void get_currdb_checksum(integrit_t *it, char sumbuf[])
 {
-    MD5_CONTEXT	context;
-    char	buf[BUFSIZ];
-    char	*fname	 = it->currdbname;
-    long	n;
-    int		fd	 = open(fname, O_RDONLY);
+    DIGEST_CONTEXT	context;
+    char		buf[BUFSIZ];
+    char		*fname	 = it->currdbname;
+    long		n;
+    int			fd	 = open(fname, O_RDONLY);
 
     if (fd == -1)
       die(__FUNCTION__, "Error: opening file (%s): %s",
 	  fname, strerror(errno));
-    md5_init(&context);
+    digest_init(&context);
     while ( (n = read(fd, buf, BUFSIZ)) ) {
       if (n == -1)
 	die(__FUNCTION__, "Error: reading file (%s): %s",
 	    fname, strerror(errno));
-      md5_write(&context, (uint8_t*) buf, (unsigned long) n);
+      digest_write(&context, (uint8_t*) buf, (unsigned long) n);
     }
-    (void) close(fd);
-    md5_final(&context);
-
-    /* It would be faster to use context.buf directly, but we only
-     * do an md5 once.
-     */
-    memcpy(sumbuf, md5_read(&context), MD5_DIGEST_LENGTH);
-    /* memcpy(sumbuf, context.buf, MD5_DIGEST_LENGTH); */
+    close(fd);
+    digest_final(&context);
+    memcpy(sumbuf, digest_read(&context), DIGEST_LENGTH);
 }
 
 static void show_currdb_checksum_abbrev(integrit_t *it, char *sumbuf, size_t n)
 {
     char	*fname	 = it->currdbname;
 
-    fputs(PROGNAME ": current-state db md5sum -------------- \n"
+    fputs(PROGNAME ": current-state db " DIGEST_NAME " -------------- \n"
 	  PROGNAME ": ", stdout);
     hexprint(stdout, (const unsigned char*) sumbuf, n);
     fputs("  ", stdout);
@@ -150,7 +145,7 @@ static void show_currdb_checksum_xml(integrit_t *it,
 int main(int argc, char *argv[])
 {
     integrit_t	it;
-    char	newdb_checksum[MD5_DIGEST_LENGTH];
+    char	newdb_checksum[DIGEST_LENGTH];
     wft_context_t wftctx	 = { 0, };
     int		ret;
 
@@ -173,6 +168,10 @@ int main(int argc, char *argv[])
     options_announce(stdout, &it);
 
     /* todo: use shared file locking with fcntl */
+    if (it.do_check && it.do_update &&
+	!strcmp(it.knowndbname, it.currdbname))
+      die(__FUNCTION__, "current and known db cannot be the same file");
+
     if (it.do_check)
       open_known_cdb(&it);
     if (it.do_update)
@@ -183,9 +182,11 @@ int main(int argc, char *argv[])
       wftctx.callback	 = process_file;
       wftctx.cb_data	 = &it;
       wftctx.options	 = it.verbose > 0 ? WFT_VERBOSE : 0;
-      if ( (ret = walk_file_tree(&wftctx)) == WFT_ERROR
-	   || ret == WFT_OPENDIR_FAIL)
+      wftctx.options	|= it.stop_on_err > 0 ? WFT_STOP_ON_ERR : 0;
+      if ( (ret = walk_file_tree(&wftctx)) == WFT_ERROR )
 	DIE("walk_file_tree");
+      else if(ret == WFT_SOME_ERR)
+	it.exit_status	|= INTEGRIT_EXIT_FAILURE;
     }
     
     if (it.do_update) {
@@ -205,7 +206,7 @@ int main(int argc, char *argv[])
     }
     if (it.do_update) {
       if (it.output == OUTPUT_XML)
-	show_currdb_checksum_xml(&it, "MD5",
+	show_currdb_checksum_xml(&it, DIGEST_NAME,
 				 newdb_checksum, sizeof(newdb_checksum));
       else
 	show_currdb_checksum_abbrev(&it,
