@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -130,7 +130,7 @@ void options_announce(FILE *out, integrit_t *it)
 
 void options_init(integrit_t *it)
 {
-    it->conffile		 = NULL;
+    it->conffile	 = NULL;
     it->knowndbname	 = NULL;
     memset(&it->knowndb, 0, sizeof(it->knowndb));
     it->currdbname	 = NULL;
@@ -141,7 +141,8 @@ void options_init(integrit_t *it)
     if (hashtbl_init(it->ruleset, 20) == -1)
       DIE("initializing hashtbl");
     it->verbose		 = 1;
-    it->do_check		 = 0;
+    it->stop_on_err	 = 1;
+    it->do_check	 = 0;
     it->do_update	 = 0;
     it->default_flags	 = RULE_SUM | RULE_INODE | RULE_PERMS | 
             RULE_TYPE | RULE_DEVICETYPE | RULE_NLINK | RULE_UID | RULE_GID | 
@@ -225,8 +226,14 @@ inline static void do_assignment(integrit_t *it, char *buf, char *eq)
 	die_noprop(property, __FUNCTION__);
       remove_first_newline(val);
       it->root	 = xstrdup(val);
+    } else if ( (property = strstr(buf, "stop_on_err")) ) {
+      EATSPACE(val);
+      if (! *val)
+	die_noprop(property, __FUNCTION__);
+      remove_first_newline(val);
+      it->stop_on_err	 = atoi(val);
     } else {
-      die(__FUNCTION__, "Error: unknown property: %s\n", property);
+      die(__FUNCTION__, "Error: unknown property: %s", property);
     }
 }
 
@@ -438,9 +445,9 @@ void options_set(integrit_t *it, int argc, char *argv[])
 	do_rule(it, cp);
     }
     if (! it->knowndbname)
-      die(__FUNCTION__, "Error: known database unspecified\n");
+      die(__FUNCTION__, "Error: known database unspecified");
     if (! it->currdbname)
-      die(__FUNCTION__, "Error: current database unspecified\n");
+      die(__FUNCTION__, "Error: current database unspecified");
     if (! it->root)
-      die(__FUNCTION__, "Error: root search directory unspecified\n");
+      die(__FUNCTION__, "Error: root search directory unspecified");
 }
