@@ -1,6 +1,6 @@
 /*
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -40,7 +40,7 @@ typedef enum ruleflag {
   RULE_CTIME		= 0x800,
   RULE_RESET_ATIME	= 0x1000,
   RULE_TYPE		= 0x2000,
-  RULE_DEVICETYPE	= 0x4000,
+  RULE_DEVICETYPE	= 0x4000
 } ruleflag;
 
 #endif
