@@ -1,6 +1,6 @@
 /* ls.c
 integrit - file integrity verification system
-Copyright (C) 2005 Ed L. Cashin
+Copyright (C) 2006 Ed L. Cashin
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -36,7 +36,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #else
 #error No stdint.h or inttypes.h found.
 #endif
-#include	"gnupg/sha1.h"
+#include	"digest.h"
 #include	"elcerror_p.h"
 #include	"elcerror.h"
 #include	"dbinfo.h"
@@ -57,10 +57,10 @@ typedef struct options {
 /* based on (but simplified from) function by the same name in eachfile.c */
 static void do_checksum(const char *filename, dbinfo *dbinf)
 {
-    SHA1_CONTEXT	context;
-    char	buf[BUFSIZ];
-    int		n;
-    int		fd	 = open(filename, O_RDONLY);
+    DIGEST_CONTEXT	context;
+    char		buf[BUFSIZ];
+    int			n;
+    int			fd	 = open(filename, O_RDONLY);
 
     if (fd == -1) {
       /* just zero out the checksum on errors (usually permission denied) */
@@ -68,16 +68,17 @@ static void do_checksum(const char *filename, dbinfo *dbinf)
       return;
     }
 
-    sha1_init(&context);
-    while ( (n = read(fd, buf, BUFSIZ)) )
-      sha1_write(&context, buf, n);
-    close(fd);
-    sha1_final(&context);
+    digest_init(&context);
+    while ( (n = read(fd, buf, BUFSIZ)) > 0)
+      digest_write(&context, (uint8_t*) buf, n);
 
-    /* It is faster but slightly dirtier to use context.buf directly.
-     */
-    /* memcpy(dbinf->sum, sha1_read(&context), SHA1_DIGEST_LENGTH); */
-    memcpy(dbinf->sum, context.buf, SHA1_DIGEST_LENGTH);
+    if (n == -1)		/* read error */
+      warn(__FUNCTION__, "Warning: read from file (%s) failed: %s",
+	   filename, strerror(errno));
+
+    close(fd);
+    digest_final(&context);
+    memcpy(dbinf->sum, digest_read(&context), DIGEST_LENGTH);
 }
 
 /* over-optimized version of (! strcmp(filename, "..")) */
